HyprCycle

Struct HyprCycle 

pub struct HyprCycle { /* private fields */ }
Represents the total functionality of the program. It can inspect the connected monitors, the extant workspaces, and can switch between workspaces.

Implementations

Source

impl HyprCycle

pub fn parse_args() -> Args

pub fn new(connection: Box<dyn HyprlandClient>) -> HyprCycle

The connection can be real or a mock object, as seen in the tests in src/service.rs.

pub fn real() -> Result<HyprCycle>

This function builds a version of the service backed by a real HyprlandConnection. It’s just for convenience to keep main() clean.

pub fn get_focused_monitor(&self) -> Result<OwnedMonitor>

In Hyprland, only one monitor can be in focus at a time. This function returns that monitor.

pub fn get_workspaces_for_monitor( &self, monitor: &OwnedMonitor, ) -> Result<Vec<OwnedWorkspace>>

Returns a sorted list of the workspaces bound to the provided monitor. Throws an error if the provided monitor doesn’t have any workspaces bound to it.

pub fn get_current_workspace(&self) -> Result<OwnedWorkspace>

Returns the workspace that’s active on the monitor that’s in focus

pub fn get_target_workspace( &self, direction: Direction, ) -> Result<OwnedWorkspace>

The index of the sorted list of workspaces tells us where to target the upcoming workspace switch.

pub fn switch_to_workspace(&self, target: &OwnedWorkspace) -> Result<()>